@@ -34,6 +34,8 @@ from .signature_ import Signature
 
 class JOSEPayload:
     __module__: str = 'ckms.jose'
+    _allow_compact: bool
+    _allow_flattened: bool
     _aad: bytes | None = None
     _ciphertext: CipherText | None = None
     _claims: ClaimSet | None = None
@@ -65,7 +67,9 @@ class JOSEPayload:
         encryption: str = DEFAULT_CONTENT_ENCRYPTION_ALGORITHM,
         encryption_key: Encrypter | None = None,
         protected: dict[str, Any] | None = None,
-        aad: bytes | dict[str, Any] |  None = None
+        aad: bytes | dict[str, Any] |  None = None,
+        allow_compact: bool = True,
+        allow_flattened: bool = True
     ):
         """Initialize a new :class:`JOSEObject` instance.
         
@@ -86,6 +90,8 @@ class JOSEPayload:
         if isinstance(aad, dict):
             aad = b64encode_json(aad)
         self._aad = aad
+        self._allow_compact = allow_compact
+        self._allow_flattened = allow_flattened
         self._content = None
         self._encryption = encryption
         self._payload = payload
@@ -175,34 +181,6 @@ class JOSEPayload:
             else not self.is_multisigned()
         )
 
-    def compress_jwe(
-        self,
-        jwe: dict[str, Any],
-        compact: bool = False
-    ) -> str:
-        """Flatten JSON Web Encryption (JWE) `jwe` if there is a single recipient
-        and `compact` is ``False`, otherwise use compact serialization or JSON
-        serialization if there are multiple recipients.
-        """
-        is_single = len(jwe['recipients']) == 1
-        result: str | dict[str, Any] = jwe
-        if is_single:
-            recipient = jwe['recipients'][0]
-            result.update(recipient)
-            del result['recipients']
-            if compact:
-                result = (
-                    f"{result['protected']}."
-                    f"{result['encrypted_key']}."
-                    f"{result.get('iv') or ''}."
-                    f"{result['ciphertext']}."
-                    f"{result.get('tag') or ''}"
-                )
-
-        if isinstance(result, dict):
-            result = json.dumps(result)
-        return result
-
     def get_payload(self) -> bytes:
         """Return the payload of a JWE or JWS."""
         # If JOSEPayload._content is None here, then there are no signers and
@@ -421,6 +399,8 @@ class JOSEPayload:
         compact: bool,
         flatten: bool
     ) -> str:
+        compact = compact and self._allow_compact
+        flatten = flatten and self._allow_flattened
         jwe: dict[str, Any] | str = obj
         recipients = jwe.get('recipients') or []
         if len(recipients) == 1 and (flatten or compact):
@@ -453,6 +433,8 @@ class JOSEPayload:
         compact: bool,
         flatten: bool
     ) -> str:
+        compact = compact and self._allow_compact
+        flatten = flatten and self._allow_flattened
         jws: dict[str, Any] | str = obj
         signatures = jws.get('signatures') or []
         if len(signatures) == 1 and (flatten or compact):
