@@ -76,7 +76,7 @@ class IProvider:
     def calculate_kid(self, value: Any) -> Any:
         return self.inspector.calculate_kid(value)
 
-    def jwk(self, spec: Any, private: bool) -> Any:
+    def jwk(self, spec: Any, private: bool, **claims: Any) -> Any:
         """Create a JWK from a key specification."""
         raise NotImplementedError
 
